<template>
    <v-card>
        <Head title="Add Payment"/>
        <v-card-title>Create Payment</v-card-title>
        <v-divider/>
        <v-card-text>
            <v-form>
                <v-row>
                    <v-col cols="6">
                        <v-row>
                            <v-col cols="12">
                                <v-autocomplete item-text="tenant.first_name" item-value="id" v-model="form.lease_id" :items="leases" dense outlined :loading="loading" :error-messages="error.lease_id" label="Lease"></v-autocomplete>
                            </v-col>

                            <v-col cols="12">
                                <v-text-field label="Amount" type="number" v-model="form.amount" :loading="loading" :error-messages="error && !form.amount ? ['This field is required.'] : '' " outlined dense></v-text-field>
                            </v-col>

                        </v-row>
                    </v-col>
                    <v-col cols="6">
                        <v-row>

                            <v-col cols="12">
                                <v-text-field label="Count" v-model="form.count" :loading="loading" :error-messages="error  && !form.count ? ['This field is required.'] : '' " outlined dense></v-text-field>
                            </v-col>

                            <v-col cols="12">
                                <v-text-field label="Date" type="date" v-model="form.date" :loading="loading" :rules="rules" :error-messages="error && !form.date ? ['This field is required.'] : '' " outlined dense></v-text-field>
                            </v-col>

                        </v-row>
                    </v-col>
                </v-row>
            </v-form>
        </v-card-text>
        <v-card-actions>
            <v-row justify="end" align="center" class="mr-5 mb-3">
                <v-btn :loading="loading" @click="storePayment" color="primary">Save Changes
                    <v-icon right>mdi-content-save-outline</v-icon>
                </v-btn>
            </v-row>
        </v-card-actions>
    </v-card>
</template>

<script>
import DashboardLayout from "../../Components/Layouts/Dashboard.vue";
import Payment from "./Payment.vue";

export default {
    name: "Create",
    layout: [DashboardLayout, Payment],
    data() {
        return {
            leases: this.$page.props.leases,
            loading: false,
            error: false,
            rules: [
                value => !!value || 'Please fill this field.',
                value => (value && value.length >= 3) || 'Min 3 characters',
            ],
            form: {
                lease_id: '',
                amount: '',
                count: '',
                period: '',
                date: ''
            }
        }
    },
    methods: {
        storePayment() {
            this.form.period = 'test-period' //period
            this.$inertia.post(this.$route('payment.store'), this.form, {
                onBefore: () => {
                    this.loading = true
                },
                onSuccess: (page) => {
                    this.showSnack(["Successfully saved payment!"])
                },
                onError: (errors) => {
                    if (errors && Object.values(errors).length) {
                        this.showSnack([Object.values(errors)[0], "error"])
                    }
                },
                onFinish: visit => {
                    this.loading = false
                },
            });
        }
    },
    mounted() {
    }
}
</script>

<style scoped>

</style>
